@@ -1052,6 +1052,7 @@ MainWindow::MainWindow()
     loadConfig();
 
     connect(DocumentFactory::instance(), &DocumentFactory::modifiedDocumentListChanged, this, &MainWindow::slotModifiedDocumentListChanged);
+    connect(qApp, &QApplication::focusChanged, this, &MainWindow::onFocusChanged);
 
 #ifdef HAVE_QTDBUS
     d->mMpris2Service =
@@ -2080,4 +2081,17 @@ void MainWindow::replaceLocation()
     }
 }
 
+void MainWindow::onFocusChanged(QWidget *old, QWidget *now)
+{
+    if (old == nullptr) {
+        if (now != nullptr && isFullScreen()) {
+            d->setScreenSaverEnabled(false);
+        }
+    } else {
+        if (now == nullptr) {
+            d->setScreenSaverEnabled(true);
+        }
+    }
+}
+
 } // namespace
